@@ -392,6 +392,10 @@ Explode.explodeEntity = function(entity, options) {
         }
     }
 
+    else if (isWipeoutEntity(entity)) {
+        ret.push(entity.getData().getBoundary());
+    }
+
     // explode spline into polyline with arc or line segments:
     else if (isSplineEntity(entity)) {
         var spline = entity.getData().castToShape();
@@ -412,10 +416,21 @@ Explode.explodeEntity = function(entity, options) {
         if (entity.isSolid()) {
             for (k=0; k<entity.getLoopCount(); k++) {
                 var shapes = entity.getLoopBoundary(k);
-                for (n=0; n<shapes.length; n++) {
-                    shape = shapes[n];
+                if (shapes.length===1) {
+                    // polyline boundary:
+                    shape = shapes[0];
                     ret.push(shape.clone());
                 }
+                else {
+                    // loose segments:
+                    var pl = new RPolyline();
+                    for (n=0; n<shapes.length; n++) {
+                        shape = shapes[n];
+                        pl.appendShape(shape.clone());
+                        //ret.push(shape.clone());
+                    }
+                    ret.push(pl);
+                }
             }
         }
         else {
